@@ -56,12 +56,12 @@ export const Caching = (props: Props) => {
   const { pageId, dataSource, loadDataSource, loadDataSourceCache, loadDataSourceMeta, enableDataSourceCache } = props;
 
   useEffect(() => {
-    setEnabled(props.enabled);
+    setEnabled(dataSource.jsonData?.disableGrafanaCache ? false : props.enabled);
     setUseDefaultTTL(props.useDefaultTTL);
     setTtlQueriesMs(props.ttlQueriesMs);
     setTtlResourcesMs(props.ttlResourcesMs);
     setLoading(false);
-  }, [props.useDefaultTTL, props.ttlQueriesMs, props.ttlResourcesMs, props.enabled]);
+  }, [props.useDefaultTTL, props.ttlQueriesMs, props.ttlResourcesMs, props.enabled, dataSource.jsonData?.disableGrafanaCache]);
 
   useEffect(() => {
     loadDataSource(pageId).then(loadDataSourceMeta);
