@@ -1,12 +1,18 @@
-import { registerEchoBackend, featureEnabled, config } from '@grafana/runtime';
-import { MetaAnalyticsBackend } from './MetaAnalyticsBackend';
-import { initAnalyticsDrawer } from './AnalyticsDrawer/AnalyticsDashNav';
-import { initPresenceIndicators } from './PresenceIndicators';
+import { config, featureEnabled, registerEchoBackend } from '@grafana/runtime';
+import { getConfig } from 'app/core/config';
 import { contextSrv } from 'app/core/services/context_srv';
 
+import { initAnalyticsDrawer } from './AnalyticsDrawer/AnalyticsDashNav';
+import { MetaAnalyticsBackend } from './MetaAnalyticsBackend';
+import { initPresenceIndicators } from './PresenceIndicators';
+
 export const initMetaAnalytics = () => {
+  if (!getConfig().analytics?.enabled) {
+    return
+  }
+
   if (featureEnabled('analytics')) {
-    registerEchoBackend(new MetaAnalyticsBackend({ url: '/api/ma/events' }));
+    registerEchoBackend(new MetaAnalyticsBackend({ url: getMetaAnalyticsUrl() }));
 
     const user = contextSrv.user;
     if (user.isSignedIn) {
@@ -17,3 +23,10 @@ export const initMetaAnalytics = () => {
     initAnalyticsDrawer();
   }
 };
+
+const getMetaAnalyticsUrl = () => {
+const publicDashboardAccessToken = getConfig().publicDashboardAccessToken;
+  return publicDashboardAccessToken !== ''
+    ? `api/public/ma/events/${publicDashboardAccessToken}`
+    : 'api/ma/events';
+};
